DecompressedReader

Enum DecompressedReader 

pub enum DecompressedReader<R> {
    Unknown(Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>),
    Gzip(GzipDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>),
    Bzip(BzDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>),
    Xz(XzDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>),
    Zstd(ZstdDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>),
}

Variants



Unknown(Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>)



Gzip(GzipDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>)



Bzip(BzDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>)



Xz(XzDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>)



Zstd(ZstdDecoder<Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>)

Implementations

Source

impl<R> DecompressedReader<R>

pub(crate) fn project<'pin>( self: Pin<&'pin mut Self>, ) -> DecompressedReaderProj<'pin, R>

Source

impl<R: AsyncRead + Unpin> DecompressedReader<R>

async fn buffer_magic( r: R, ) -> Result<(SmallBuf<BYTES_NEEDED>, Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>)>

Reads up to BYTES_NEEDED bytes from the underlying reader, and returns those Bytes as a SmallBuf, as well as a reader allowing to read all data

Source

impl<R: AsyncBufRead + Unpin> DecompressedReader<R>

pub async fn new(reader: R) -> Result<Self>

Checks the passed reader for a suitable compression magic to be present, pulling up to 6 bytes of data. If there is, returns a reader which allows reading decompressed data. Else, returns a reader that reads the uncompressed/undetected data (including the up to 6 bytes).

pub fn as_unknown_inner( &mut self, ) -> Option<&mut Chain<Cursor<SmallBuf<BYTES_NEEDED>>, R>>

The decoders don’t implement AsyncBufRead, so we cannot implement it for DecompressedReader. However, in the unknown case we only wrap R (and the buffer we read so far), they are AsyncBufRead. This provides a way to get a mutable reference to it.