import_path_as_nar_ca

Function import_path_as_nar_ca 

pub async fn import_path_as_nar_ca<BS, DS, PS, NS, P>(
    path: P,
    name: impl AsRef<str>,
    blob_service: BS,
    directory_service: DS,
    path_info_service: PS,
    nar_calculation_service: NS,
) -> Result<PathInfo, Error>
Ingest the contents at the given path path into castore, and registers the resulting root node in the passed PathInfoService, using the “NAR sha256 digest” and the passed name for output path calculation. Inserts the PathInfo into the PathInfoService and returns it back to the caller. The name should have been checked by nix_compat::store_path::validate_name before, to avoid unnecessarily importing, but will prevent the PathInfo from being created in case of an invalid name.