CountingWriter

Struct CountingWriter 

struct CountingWriter<'a> {
    bytes_written: &'a AtomicU64,
}
A writer that only counts the number of bytes written so far, updating a &AtomicU64. We can’t use count_write::CountWrite. As we hand out a &mut Write to the NAR writer, we can’t have other read-only references until we drop it, yet we need to be able to access the current offsets to put in the listing scructure we build up at the same time.

Fields

bytes_written: &'a AtomicU64