pub struct MockNarCalculationService {
NarCalculationService_expectations: MockNarCalculationService_NarCalculationService,
}Fields
NarCalculationService_expectations: MockNarCalculationService_NarCalculationServiceImplementations
Sourceimpl MockNarCalculationService
impl MockNarCalculationService
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockNarCalculationService
impl MockNarCalculationService
Sourcepub fn expect_calculate_nar(&mut self) -> &mut Expectation
pub fn expect_calculate_nar(&mut self) -> &mut Expectation
Create an Expectation for mocking the calculate_nar method