pub struct Reader<'bs, BS: BlobService + 'bs> {
segments: Segments,
pos: u64,
blob_service: BS,
rd: Box<dyn AsyncBufRead + Send + Unpin + 'bs>,
}Fields
segments: Segmentspos: u64blob_service: BSrd: Box<dyn AsyncBufRead + Send + Unpin + 'bs>Implementations
Sourceimpl<'bs, BS: BlobService + 'bs> Reader<'bs, BS>
impl<'bs, BS: BlobService + 'bs> Reader<'bs, BS>
Sourceimpl<'bs, BS: BlobService + Clone + 'bs> Reader<'bs, BS>
impl<'bs, BS: BlobService + Clone + 'bs> Reader<'bs, BS>
Sourcepub async fn new(
root_node: &Node,
blob_service: BS,
directory_service: impl DirectoryService,
) -> Result<Self, RenderError>
pub async fn new( root_node: &Node, blob_service: BS, directory_service: impl DirectoryService, ) -> Result<Self, RenderError>
Creates a new seekable NAR renderer for the given castore root node.
This function pre-fetches the directory closure using get_recursive() and assembles the
NAR structure, except the file contents which are stored as ‘holes’ with references to a blob
of a specific BLAKE3 digest and known size.
The AsyncRead implementation will then switch between serving the
precomputed literal segments, and the appropriate blob for the file
contents.
pub fn nar_size(&self) -> u64