pub struct MockPathInfoService {
PathInfoService_expectations: MockPathInfoService_PathInfoService,
}Expand description
The base trait all PathInfo services need to implement.
Fields
PathInfoService_expectations: MockPathInfoService_PathInfoServiceImplementations
Sourceimpl MockPathInfoService
impl MockPathInfoService
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockPathInfoService
impl MockPathInfoService
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_has(&mut self) -> &mut Expectation
pub fn expect_has(&mut self) -> &mut Expectation
Create an Expectation for mocking the has method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_list(&mut self) -> &mut Expectation
pub fn expect_list(&mut self) -> &mut Expectation
Create an Expectation for mocking the list method
Sourcepub fn expect_nar_calculation_service(&mut self) -> &mut Expectation
pub fn expect_nar_calculation_service(&mut self) -> &mut Expectation
Create an Expectation for mocking the nar_calculation_service method