pub enum ValidatePathInfoError {
InvalidReferenceDigestLen(usize, usize),
NoEntryPresent,
InvalidRootNode(DirectoryError),
InvalidNodeName(Vec<u8>, Error),
InvalidNarSha256DigestLen(usize),
InconsistentNumberOfReferences(usize, usize),
InvalidNarinfoReferenceName(usize, String),
InconsistentNarinfoReferenceNameDigest(usize, [u8; 20], [u8; 20]),
InvalidDeriverField(Error),
NarInfoFieldMissing,
InvalidCaField(ConvertCAError),
InvalidSignature(usize, SignatureError),
}Expand description
Errors that can occur during the validation of PathInfo messages.
Variants
InvalidReferenceDigestLen(usize, usize)
Invalid length of a reference
NoEntryPresent
No entry present
InvalidRootNode(DirectoryError)
Node fails validation
InvalidNodeName(Vec<u8>, Error)
Invalid node name encountered. Root nodes in PathInfos have more strict name requirements
InvalidNarSha256DigestLen(usize)
The digest in narinfo.nar_sha256 has an invalid len.
InconsistentNumberOfReferences(usize, usize)
The number of references in the narinfo.reference_names field does not match the number of references in the .references field.
InvalidNarinfoReferenceName(usize, String)
A string in narinfo.reference_names does not parse to a store_path::StorePath.
InconsistentNarinfoReferenceNameDigest(usize, [u8; 20], [u8; 20])
The digest in the parsed .narinfo.reference_names[i] does not match
the one in .references[i].`
InvalidDeriverField(Error)
The deriver field is invalid.
NarInfoFieldMissing
The narinfo field is missing
InvalidCaField(ConvertCAError)
The ca field is invalid
InvalidSignature(usize, SignatureError)
The signature at position is invalid