pub struct ServiceUrlsGrpc {
castore_service_addrs: ServiceUrlsGrpc,
path_info_service_addr: String,
}Expand description
Provides a set of clap arguments to configure snix-[ca]store services.
This particular variant has defaults tailored for usecases accessing data from another running snix daemon, via gRPC.
Fields
castore_service_addrs: ServiceUrlsGrpcpath_info_service_addr: StringTrait Implementations
Sourceimpl Args for ServiceUrlsGrpc
impl Args for ServiceUrlsGrpc
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Clone for ServiceUrlsGrpc
impl Clone for ServiceUrlsGrpc
Sourcefn clone(&self) -> ServiceUrlsGrpc
fn clone(&self) -> ServiceUrlsGrpc
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandFactory for ServiceUrlsGrpc
impl CommandFactory for ServiceUrlsGrpc
Sourceimpl From<ServiceUrlsGrpc> for ServiceUrls
impl From<ServiceUrlsGrpc> for ServiceUrls
Sourcefn from(urls: ServiceUrlsGrpc) -> ServiceUrls
fn from(urls: ServiceUrlsGrpc) -> ServiceUrls
Converts to this type from the input type.
Sourceimpl FromArgMatches for ServiceUrlsGrpc
impl FromArgMatches for ServiceUrlsGrpc
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for ServiceUrlsGrpc
impl Parser for ServiceUrlsGrpc
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)