pub struct ServiceUrlsMemory {
castore_service_addrs: ServiceUrlsMemory,
path_info_service_addr: String,
}Expand description
Provides a set of clap arguments to configure snix-[ca]store services.
This particular variant has defaults tailored for usecases keeping all data in memory. It’s currently used in snix-cli-eval, as we don’t really care about persistency there yet, and using something else here might make some perf output harder to interpret.
Fields
castore_service_addrs: ServiceUrlsMemorypath_info_service_addr: StringTrait Implementations
Sourceimpl Args for ServiceUrlsMemory
impl Args for ServiceUrlsMemory
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Clone for ServiceUrlsMemory
impl Clone for ServiceUrlsMemory
Sourcefn clone(&self) -> ServiceUrlsMemory
fn clone(&self) -> ServiceUrlsMemory
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandFactory for ServiceUrlsMemory
impl CommandFactory for ServiceUrlsMemory
Sourceimpl From<ServiceUrlsMemory> for ServiceUrls
impl From<ServiceUrlsMemory> for ServiceUrls
Sourcefn from(urls: ServiceUrlsMemory) -> ServiceUrls
fn from(urls: ServiceUrlsMemory) -> ServiceUrls
Converts to this type from the input type.
Sourceimpl FromArgMatches for ServiceUrlsMemory
impl FromArgMatches for ServiceUrlsMemory
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for ServiceUrlsMemory
impl Parser for ServiceUrlsMemory
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)