struct CountingWriter<'a> {
bytes_written: &'a AtomicU64,
}Expand description
A writer that only counts the number of bytes written so far,
updating a &AtomicU64.
We can’t use count_write::CountWrite.
As we hand out a &mut Write to the NAR writer, we can’t have other read-only
references until we drop it, yet we need to be able to access the current
offsets to put in the listing scructure we build up at the same time.
Fields
bytes_written: &'a AtomicU64Trait Implementations
Sourceimpl Write for CountingWriter<'_>
impl Write for CountingWriter<'_>
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
fn write_all(&mut self, buf: &[u8]) -> Result<(), Error>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
write_all_vectored)Attempts to write multiple buffers into this writer. Read more