pub struct Segments {
segments: Vec<(u64, Segment)>,
total_len: u64,
}Expand description
Contains a list of Segments. For each segment, stores its offset to allow binary search seeking.
Fields
segments: Vec<(u64, Segment)>total_len: u64Implementations
Sourceimpl Segments
impl Segments
Sourcepub fn from_root_node_and_directories(
root_node: &Node,
directories: &HashMap<B3Digest, Directory>,
) -> Self
pub fn from_root_node_and_directories( root_node: &Node, directories: &HashMap<B3Digest, Directory>, ) -> Self
Construct segments that can be used to assemble a NAR, using the given root_node and directories. Panics if the directory closure is not complete.
Sourcepub fn reader_for_offset<'bs, BS: BlobService + Clone + 'bs>(
&self,
offset: u64,
segment_concurrency: usize,
blob_service: BS,
) -> Box<dyn AsyncBufRead + Send + Unpin + 'bs>
pub fn reader_for_offset<'bs, BS: BlobService + Clone + 'bs>( &self, offset: u64, segment_concurrency: usize, blob_service: BS, ) -> Box<dyn AsyncBufRead + Send + Unpin + 'bs>
Provides a AsyncBufRead into a Segments from the given offset.
A BlobService to read blobs from needs to be specified, as well as the desired concurrency (for segments, not blobs).
This does not implement AsyncSeek, seeking can be done by calling this again with another offset.
pub fn total_len(&self) -> u64
fn push(&mut self, elem: Segment)