pub struct NixHTTPPathInfoService<BS: Clone, DS> {
instance_name: String,
base_url: Url,
http_client: ClientWithMiddleware,
blob_service: BS,
directory_service: DS,
layered_blob_service: Cache<BS, GRPCBlobService<Channel>>,
layered_directory_service: Cache<DS, GRPCDirectoryService<Channel>>,
trusted_public_keys: Vec<VerifyingKey>,
force_download_nar: bool,
}Expand description
NixHTTPPathInfoService acts as a bridge in between the Nix HTTP Binary cache protocol provided by Nix binary caches such as cache.nixos.org, and the Snix Store Model. It implements the PathInfoService trait in an interesting way: Every PathInfoService::get fetches the .narinfo and referred NAR file, inserting components into a BlobService and DirectoryService, then returning a PathInfo struct with the root.
Due to this being quite a costly operation, clients are expected to layer this service with store composition, so they’re only ingested once.
The client is expected to be (indirectly) using the same BlobService and DirectoryService, so able to fetch referred Directories and Blobs. PathInfoService::put is not implemented and returns an error if called. TODO: what about reading from nix-cache-info?
Fields
instance_name: Stringbase_url: Urlhttp_client: ClientWithMiddlewareblob_service: BSdirectory_service: DSlayered_blob_service: Cache<BS, GRPCBlobService<Channel>>A BlobService Cache with ‘far’ talking to the configured endpoint over gRPC. This is used when validating castore-infused NAR URLs in NARInfos. We rely on Cache to insert into ‘near’.
layered_directory_service: Cache<DS, GRPCDirectoryService<Channel>>A DirectoryService Cache with ‘far’ talking to the configured endpoint over gRPC. This is used when validating castore-infused NAR URLs in NARInfos. We rely on Cache to insert into ‘near’.
trusted_public_keys: Vec<VerifyingKey>An optional list of narinfo::VerifyingKey. If the list is not empty, the .narinfo files received need to have correct signature by at least one of these.
force_download_nar: boolForce the download of NAR files, even if there’s castore-infused NAR URLs.
Implementations
Sourceimpl<BS, DS> NixHTTPPathInfoService<BS, DS>
impl<BS, DS> NixHTTPPathInfoService<BS, DS>